@@ -48,7 +48,7 @@ class CacheManager:
 
 class BufferedCacheManager(CacheManager):
     """
-    Buffered Cache Manager implementation. Keeps track of cache in memory.
+    Buffered Cache Manager implementation. Stored cache in memory.
     """
 
     def __init__(self, path=None):
@@ -62,10 +62,7 @@ class BufferedCacheManager(CacheManager):
 
         :rtype: :class:`generator`
         """
-        return (
-            i
-            for i in self._buf
-        )
+        return (i for i in self._buf)
 
     def read(self, name):
         """Reads cache with ``name`` if it exists."""
@@ -83,11 +80,12 @@ class BufferedCacheManager(CacheManager):
 
         els = name.split('*') # splits across *
 
+        print(els)
+
         need_remove = []
 
         for i in self._buf:
             for n, j in enumerate(els):
-                i = i.rstrip('.dat')
                 if not (
                     j == '' or (j in i and
                         (i.index(j) >= i.index(els[0 if n < 1 else n - 1]))
@@ -99,7 +97,7 @@ class BufferedCacheManager(CacheManager):
                     # ---------------------------
                     # `els` is a list of all components split across *.
                     # We check if each component of `else` is in
-                    # the file name being checked (`j in i`).
+                    # the cache name being checked (`j in i`).
                     # If the component is empty, we can skip directly.
                     # If it is, we make sure its after the previous
                     # component (second check).
@@ -131,8 +129,8 @@ class FileCacheManager(CacheManager):
 
         Path(path).mkdir(parents=True, exist_ok=True)  # Creates cache folder
 
-        ## Cache is identified with its `name` attribute. Cache can be read by keeping track of this
-        ## value and reading it with `read` later on.
+        # Cache is identified with its `name` attribute. Cache can be read by keeping track of this
+        # value and reading it with `read` later on.
 
     @property
     def path(self):
@@ -150,7 +148,7 @@ class FileCacheManager(CacheManager):
         :rtype: :class:`generator`
         """
         return (
-            i.rstrip('.dat')
+            ''.join(i.split('.')[:-1]) if i.endswith('.dat') else i
             for i in os.listdir(self._path)
         )
 
@@ -172,26 +170,27 @@ class FileCacheManager(CacheManager):
 
     def dump(self, name, data):
         """Writes data to a cache file with ``name``. ``name`` must be kept track of manually."""
+
         with open(f"{self._path}/{name}.dat", "wb") as f:
             pickle.dump(zlib.compress(pickle.dumps(data)), f)
 
     def cleanup(self, name):
         """Cleans up all cache files with a given ``name``. Supports wildcard (*) deletion."""
 
-        els = name.split('*') # splits across *
+        els = name.split('*')
 
         try:
             for i in os.listdir(self._path):
                 for n, j in enumerate(els):
-                    k = i.rstrip('.dat')
+                    k = ''.join(i.split('.')[:-1]) if i.endswith('.dat') else i
                     if not (
-                        j == '' or (j in i and
+                        j == '' or (j in k and
                             (k.index(j) >= k.index(els[0 if n < 1 else n - 1]))
                             )
                         ):
                         break
                 else:
-                    os.remove(f"{self._path}/{i}") # Delete the actual file
+                    os.remove(f"{self._path}/{i}") # Delete the file
 
         except FileNotFoundError:
             pass
