@@ -18,10 +18,10 @@ __all__ = [
     'Cel'
 ]
 
-@dataclass(frozen=True)
+@dataclass()
 class Km:
     """Kilometer."""
-    val: float
+    val: float = 0
 
     def miles(self):
         """Equivalent miles."""
@@ -30,10 +30,10 @@ class Km:
     def __repr__(self):
         return f"{self.val}"
 
-@dataclass(frozen=True)
+@dataclass()
 class Mm:
     """Milimeters."""
-    val: float
+    val: float = 0
 
     def inches(self):
         """Equivalent inches."""
@@ -42,10 +42,10 @@ class Mm:
     def __repr__(self):
         return f"{self.val}"
 
-@dataclass(frozen=True)
+@dataclass()
 class Mb:
     """Milibar."""
-    val: float
+    val: float = 0
 
     def inches(self):
         """Equivalent inches of Hg."""
@@ -54,10 +54,10 @@ class Mb:
     def __repr__(self):
         return f"{self.val}"
 
-@dataclass(frozen=True)
+@dataclass()
 class Cel:
     """Celsius."""
-    val: float
+    val: float = -273.15
 
     def fahrenheit(self):
         """Equivalent farenheit."""
